@@ -9,15 +9,17 @@ lu <- function(x, ...) UseMethod("lu")
 
 norm <- function(x, ...) UseMethod("norm")
 norm.Matrix <- function(x, type = "M", ...)
-    .Call("R_LapackPP_norm", x, as.character(type))
+    .Call("R_LapackPP_norm", x, as.character(type), PACKAGE="Matrix")
 norm.default <- function(x, type = "M", ...)
-    .Call("R_LapackPP_norm", as.matrix(x), as.character(type))
+    .Call("R_LapackPP_norm", as.matrix(x),
+          as.character(type), PACKAGE="Matrix")
 
 rcond <- function(x, ...) UseMethod("rcond")
 rcond.Matrix <- function(x, type = "O", ...)
-    .Call("R_LapackPP_rcond", x, as.character(type))
+    .Call("R_LapackPP_rcond", x, as.character(type), PACKAGE="Matrix")
 rcond.default <- function(x, type = "O", ...)
-    .Call("R_LapackPP_rcond", as.matrix(x), as.character(type))
+    .Call("R_LapackPP_rcond", as.matrix(x),
+          as.character(type), PACKAGE="Matrix")
 
 schur <- function(x, ...) UseMethod("schur")
 
