@@ -21,7 +21,7 @@
 // LAPACK++ was funded in part by the U.S. Department of Energy, the
 // National Science Foundation and the State of Tennessee.
 //
-// Modifications Copyright (C) 2000-2000 the R Development Core Team
+// Modifications Copyright (C) 2000-2000, 2002 the R Development Core Team
 //
 
 #include "lafnames.h"
@@ -38,6 +38,8 @@
 #undef append
 #endif
 
+#include <valarray>
+
 double LaUnitLowerTriangMatDouble::outofbounds_ = 0; // initialize outofbounds.
 
 double& LaUnitLowerTriangMatDouble::operator()(int i, int j)
@@ -57,7 +59,7 @@ double& LaUnitLowerTriangMatDouble::operator()(int i, int j)
 	return data_(i,j);
 }
 
-const double& LaUnitLowerTriangMatDouble::operator()(int i, int j) const
+double LaUnitLowerTriangMatDouble::operator()(int i, int j) const
 {
 
 #ifdef UNIT_LOWER_INDEX_CHK
@@ -98,7 +100,7 @@ LaMatDouble& LaUnitLowerTriangMatDouble::operator=(double s)
     return *this;
 }
 
-ostream& LaUnitLowerTriangMatDouble::printMatrix(ostream& s) const
+std::ostream& LaUnitLowerTriangMatDouble::printMatrix(std::ostream& s) const
 {
     if (*info_) {   // print out only matrix info, not actual values
 	*info_ = 0; // reset the flag
@@ -115,7 +117,7 @@ ostream& LaUnitLowerTriangMatDouble::printMatrix(ostream& s) const
 		if (i > j)
 		    s << (*this)(i,j) << "  ";
 	    }
-	    s << endl;
+	    s << std::endl;
 	}
     }
     return s;
@@ -137,7 +139,7 @@ LaUnitLowerTriangMatDouble* LaUnitLowerTriangMatDouble::solve() const
 LaMatDouble& LaUnitLowerTriangMatDouble::solve(LaMatDouble& B) const
 {				// in-place solution
     F77_CALL(dtrsm)('L', 'L', 'N', 'U', size(0), B.size(1), 1.0,
-		    &data_(0,0), gdim(0), &B(0,0), B.gdim(0));
+                    data_.addr(), gdim(0), B.addr(), B.gdim(0));
     return B;
 }
 
@@ -149,20 +151,20 @@ LaMatDouble& LaUnitLowerTriangMatDouble::solve(LaMatDouble& X, const LaMatDouble
     
 double LaUnitLowerTriangMatDouble::norm(char which) const
 {
-    VectorDouble work(size(0)); // only needed for Infinity norm
+    std::valarray<double> work(size(0)); // only needed for Infinity norm
     double val = F77_CALL(dlantr)(which, 'L', 'U', size(0), size(1),
-				  &(*this)(0,0), gdim(0), &work(0));
+                                  this->addr(), gdim(0), &work[0]);
     return val;
 }
 
 double LaUnitLowerTriangMatDouble::rcond(char which) const
 {
     double val;
-    VectorDouble work(3 * size(0));
+    std::valarray<double> work(3 * size(0));
     int info;
-    VectorInt iwork(size(0));
-    F77_CALL(dtrcon)(which, 'L', 'U', size(0), &(*this)(0,0),
-		     gdim(0), val, &work(0), &iwork(0), info);
+    std::valarray<int> iwork(size(0));
+    F77_CALL(dtrcon)(which, 'L', 'U', size(0), this->addr(),
+                     gdim(0), val, &work[0], &iwork[0], info);
     return val;
 }
 
@@ -170,8 +172,8 @@ SEXP LaUnitLowerTriangMatDouble::asSEXP() const
 {
     int m = size(0), n = size(1);
     SEXP val = PROTECT(allocMatrix(REALSXP, m, n));
-    F77_CALL(dlacpy)('L', m, n, &(*this)(0,0), gdim(0),
-		     REAL(val), m);
+    F77_CALL(dlacpy)('L', m, n, this->addr(), gdim(0),
+                     REAL(val), m);
     int ldiag = (m < n) ? m : n;
     for (int i = 0; i < ldiag; i++) // ensure the diagonal entries are 1.0
 	REAL(val)[i * (m + 1)] = 1.0;
