@@ -21,7 +21,7 @@
 // LAPACK++ was funded in part by the U.S. Department of Energy, the
 // National Science Foundation and the State of Tennessee.
 //
-// Modifications Copyright (C) 2000-2000 the R Development Core Team
+// Modifications Copyright (C) 2000-2000, 2002 the R Development Core Team
 //
 
 #include "lafnames.h"
@@ -29,6 +29,8 @@
 #include "blas3.h"
 #include "vi.h"
 
+#include <valarray>
+
 double LaUpperTriangMatDouble::outofbounds_ = 0; // initialize outofbounds.
 
 LaUpperTriangMatDouble& LaUpperTriangMatDouble::copy(const LaMatDouble &ob)
@@ -56,7 +58,7 @@ LaMatDouble& LaUpperTriangMatDouble::operator=(double s)
     return *this;
 }
 
-ostream& LaUpperTriangMatDouble::printMatrix(ostream &s) const
+std::ostream& LaUpperTriangMatDouble::printMatrix(std::ostream &s) const
 {
     if (*info_)     // print out only matrix info, not actual values
     {
@@ -74,7 +76,7 @@ ostream& LaUpperTriangMatDouble::printMatrix(ostream &s) const
 		if (j >= i)
 		    s << (*this)(i,j) << "  ";
 	    }
-	    s << endl;
+	    s << std::endl;
 	}
     }
     return s;
@@ -96,7 +98,7 @@ LaUpperTriangMatDouble* LaUpperTriangMatDouble::solve() const
 LaMatDouble& LaUpperTriangMatDouble::solve(LaMatDouble& B) const
 {				// in-place solution
     F77_CALL(dtrsm)('L', 'U', 'N', 'N', size(1), B.size(1), 1.0,
-		    &data_(0,0), gdim(0), &B(0,0), B.gdim(0));
+                    data_.addr(), gdim(0), B.addr(), B.gdim(0));
     return B;
 }
 
@@ -108,27 +110,27 @@ LaMatDouble& LaUpperTriangMatDouble::solve(LaMatDouble& X, const LaMatDouble& B)
 
 double LaUpperTriangMatDouble::norm(char which) const
 {
-    VectorDouble work(size(0));	// only needed for Infinity norm
+    std::valarray<double> work(size(0));	// only needed for Infinity norm
     return F77_CALL(dlantr)(which, 'U', 'N', size(0), size(1),
-			    &(*this)(0,0), gdim(0), &work(0));
+                            this->addr(), gdim(0), &work[0]);
 }
 
 double LaUpperTriangMatDouble::rcond(char which) const
 {
     double val;
-    VectorDouble work(3 * size(0));
+    std::valarray<double> work(3 * size(0));
     int info;
-    VectorInt iwork(size(0));
-    F77_CALL(dtrcon)(which, 'U', 'N', size(0), &(*this)(0,0),
-		     gdim(0), val, &work(0), &iwork(0), info);
+    std::valarray<int> iwork(size(0));
+    F77_CALL(dtrcon)(which, 'U', 'N', size(0), this->addr(),
+                     gdim(0), val, &work[0], &iwork[0], info);
     return val;
 }
 
 SEXP LaUpperTriangMatDouble::asSEXP() const
 {
     SEXP val = PROTECT(allocMatrix(REALSXP, size(0), size(1)));
-    F77_CALL(dlacpy)('U', size(0), size(1), &(*this)(0,0), gdim(0),
-		     REAL(val), size(0));
+    F77_CALL(dlacpy)('U', size(0), size(1), this->addr(), gdim(0),
+                     REAL(val), size(0));
     SEXP classes = PROTECT(allocVector(STRSXP, 2));
     SET_STRING_ELT(classes, 0, mkChar("UpperTriangular"));
     SET_STRING_ELT(classes, 1, mkChar("Matrix"));
